Command-Line Interface Reference
================================

Information on the commands available through Designate's Command Line
Interface (CLI) can be found in this section.

.. toctree::
   :maxdepth: 1

   designate-manage
   designate-status
